Method: Hyperkit::Client::Operations#cancel_operation
- Defined in:
- lib/hyperkit/client/operations.rb
#cancel_operation(uuid) ⇒ Sawyer::Resource
Cancel a running operation
Calling this will change the state of the operation to cancelling. Note that the operation must be cancelable, which can be ascertained by calling #operation and checking the may_cancel property.
67 68 69 |
# File 'lib/hyperkit/client/operations.rb', line 67 def cancel_operation(uuid) delete(operation_path(uuid)). end |